--
-- ItemManager - Lotro Plugin to help manage subsets of items in backpack in windows
--
-- Copyright (C) 2012   Random Augury
--
--  This program is free software: you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation, either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.
--	
--	You may contact me at: randomaugury@gmail.com

import "Turbine.UI.Lotro";

import "Augury.ItemManager.Class";
import "Augury.ItemManager.Constants";
import "Augury.ItemManager.Misc";



local defaultData = {
	opacity = 1,
	width = 8 * Constants.itemWidth + Constants.xPadding,
	height = 6 * Constants.itemHeight + Constants.yPadding,
	xPosition = 333,
	yPosition = 333,
	name = "New Window",
	visible = true,
};		

	
IMDisplay = class(Turbine.UI.Lotro.Window);

function IMDisplay:Constructor(_setKey)
	Turbine.UI.Lotro.Window.Constructor(self);
	
	self.setKey = _setKey;
	self:Load(_setKey);	
	self:SetInitialLayout()
	
	self:AddResizeZone();

	AddListener(self, "PositionChanged", function(sender, args)
		self:PositionChangedHandler(sender, args);
	end);
	AddListener(self, "SizeChanged", function(sender, args)
		self.data.width, self.data.height = self:GetSize();
	end);	
	
end;

function IMDisplay:SetName(newName)
	self.data.name = newName;
	self:SetText(self.data.name);
	self:Save();
end;

function IMDisplay:GetName()
	return self.data.name;
end;

function IMDisplay:Load(setKey)
	if (not ItemManager.finishedLoading)
	then
		self.data = Turbine.PluginData.Load(Turbine.DataScope.Server, "AuguryIMDisplay" .. setKey);
	end
	
	if (type(self.data) ~= "table")
	then
		self.data = DeepCopy(defaultData);
		self.data.name = self.data.name .. " (" .. setKey .. ")"
		self.data.xPosition = self.data.xPosition + (setKey - 1) * 30	
		self.data.yPosition = self.data.yPosition + (setKey - 1) * 30	
	end
	Debug:DumpTable(5, self.data);
end;

function IMDisplay:Save()
	Turbine.PluginData.Save(Turbine.DataScope.Server, "AuguryIMDisplay" .. self.setKey, self.data);
end;

function IMDisplay:SetInitialLayout()
	self:SetOpacity(self.data.opacity);
	self:SetSize(self.data.width, self.data.height);
	self:SetText(self.data.name);
	self:SetPosition(self.data.xPosition, self.data.yPosition);
	self:SetVisible(self.data.visible);	
	self:SetAllowDrop(true);
end;

-- Because we want windows to come back to previous position - we save every time a window is moved
-- perhaps a little extravagant but seems to work fine for me
function IMDisplay:PositionChangedHandler(sender, args)
	self.data.xPosition, self.data.yPosition = self:GetPosition();
	self:Save();
end;

-- I grabbed the way of handling the resize work from the Busy Bee plugin from Bosko
--
-- ToDo: Factor out into a class
function IMDisplay:AddResizeZone()

    self.resizeHandle = Turbine.UI.Control();
    self.resizeHandle:SetParent(self);
    self.resizeHandle:SetZOrder(100);
    self.resizeHandle:SetSize(20, 20);

	self.resizeHandle:SetPosition(self:GetWidth() - self.resizeHandle:GetWidth(), 
        self:GetHeight() - self.resizeHandle:GetHeight());
		
    self.resizeHandle.MouseDown = function(sender, args)
		sender.dragStartX = args.X;
		sender.dragStartY = args.Y;
		self.dragging = true;
	end

    self.resizeHandle.MouseMove = function(sender, args)
        local width, height = self:GetSize();
        if (self.dragging) then
            local newWidth = math.max(Constants.minWindowSize.w, width + (args.X - sender.dragStartX));
            local newHeight = math.max(Constants.minWindowSize.h, height + (args.Y - sender.dragStartY));
            self:SetSize(newWidth, newHeight);
            sender:SetPosition(self:GetWidth() - self.resizeHandle:GetWidth(), 
                self:GetHeight() - self.resizeHandle:GetHeight())
        end
    end

    self.resizeHandle.MouseUp = function(sender, args)
        self.dragging = false;
		self:Save();
    end
	
end;

function IMDisplay:SetAndSaveVisibleState(newState)
	self.data.visible = newState;
	self:SetVisible(self.data.visible);
	self:Save();
end;

function IMDisplay:Show()
	self:SetAndSaveVisibleState(true);
end;

function IMDisplay:OnClosed(sender, args)
	self:SetAndSaveVisibleState(false);
end;