--
-- ItemManager - Lotro Plugin to help manage subsets of items in backpack in windows
--
-- Copyright (C) 2012   Random Augury
--
--  This program is free software: you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation, either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.
--	
--	You may contact me at: randomaugury@gmail.com

import "Augury.ItemManager.Debug";
import "Augury.ItemManager.Class";

ItemFilter = class();

local defaultData = { itemNamesInFilter = {} };

function ItemFilter:Constructor(_setKey)
	self.setKey = _setKey;
	self:Load(_setKey);
	
	Debug:DumpTable(5, self.data);
end

function ItemFilter:Load(setKey)
	if (not ItemManager.finishedLoading)
	then
		self.data = Turbine.PluginData.Load(Turbine.DataScope.Server, "AuguryItemFilter" .. setKey);
	end
	
	if (type(self.data) ~= "table")
	then
		self.data = DeepCopy(defaultData);
	end
end;

function ItemFilter:Save()
	Turbine.PluginData.Save(Turbine.DataScope.Server, "AuguryItemFilter" .. self.setKey, self.data);
end

-- Checks to see if the item passed matches this filter.
--
-- Returns true if it does, and false if not
function ItemFilter:IsItemAMatch(theItem)
	return theItem ~= nil and self.data.itemNamesInFilter[theItem:GetName()];
end

function ItemFilter:DragDropHandler(sender, args)
	Debug:WriteLn(5, "Entering ItemFilter:DragDropHandler()");
	local shortcut = args.DragDropInfo:GetShortcut();
	
	if (shortcut ~= nil and shortcut:GetType() == Turbine.UI.Lotro.ShortcutType["Item"])
	then
		local incomingItem = shortcut:GetItem();
		
		if (incomingItem == nil)
		then
			Debug:WriteLn(1, "FilterWindow:DragDrop(...): Item was dragged but shortcut:GetItem() is returning nil");
			return;
		end
		
		if (not self.data.itemNamesInFilter[incomingItem:GetName()])
		then
			self.data.itemNamesInFilter[incomingItem:GetName()] = true;
			ExecuteListener(self, "FilterChanged", nil);
		end
	end
	
	Debug:DumpTable(1, self);
	
	self:Save();
end
