--
-- ItemManager - Lotro Plugin to help manage subsets of items in backpack in windows
--
-- Copyright (C) 2012   Random Augury
--
--  This program is free software: you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation, either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.
--	
--	You may contact me at: randomaugury@gmail.com
--
--



-- The main function, corresponding to the plugin. This is the first thing loaded
-- see the Astah UML file for class diagram
--
-- Note that I have been pretty lazy with validating the content of the save files
-- too bad - it would take too long. Might add this later, but probably not.


import "Augury.ItemManager.Class";
import "Augury.ItemManager.Debug";
import "Augury.ItemManager.IMSet";

ItemManager = class();

local defaultData = {nextWindowID = 2, itemSetData = {{setKey = "1"}}};

function ItemManager:Constructor()
	Debug:WriteLn(5, "ItemManager:Constructor()");
	ItemManager.finishedLoading = false;
	ItemManager:Load();
	ItemManager.finishedLoading = true; -- needed because the Turbine.PluginData.Load method
									   -- works differently between initial load and later
end;

function ItemManager:Run()
	Debug:WriteLn(2, "TODO: If all windows are not visible, on load it should pop up the yet to be created mgt menu");
end;

function ItemManager:Load()
	ItemManager:LoadPluginData();
	ItemManager:LoadAllIMSets();
end;

function ItemManager:ShowAll()
	for k, v in pairs(self.itemSets)
	do
		v:Show();
	end;
	
end;

function ItemManager:Save()
	Turbine.PluginData.Save(Turbine.DataScope.Server, "AuguryItemManager", self.data);
end;

function ItemManager:MakeNewWindow()
	local nextID = self.data.nextWindowID;
	self.data.itemSetData[nextID] = IMSet(nextID);
	self.data.nextWindowID = nextID + 1;
	self:Save();
end;


-- Load information about existing IMSets. If there is nothing saved
-- use the default window.
function ItemManager:LoadPluginData()
	self.data = Turbine.PluginData.Load(Turbine.DataScope.Server, "AuguryItemManager");
	if (type(self.data) ~= "table")
	then
		self.data = defaultData;
		self:Save();
	end
	Debug:DumpTable(5, self.data);
end;

-- Load all the other IMSets
function ItemManager:LoadAllIMSets()
	self.itemSets = {};
	for k, v in pairs(self.data.itemSetData)
	do
		self.itemSets[v["setKey"]] = IMSet(v["setKey"]);
	end;
end;

ItemManager:Constructor();
